@@ -21,19 +21,14 @@
 #include <unistd.h>
 #endif
 #include <getopt.h>
-#include <kiwix/tools/pathTools.h>
 #include <kiwix/tools/stringTools.h>
 #include <kiwix/manager.h>
-#include <kiwix/downloader.h>
 #include <cstdlib>
 #include <iostream>
 
-#include <thread>
-#include <chrono>
-
 using namespace std;
 
-enum supportedAction { NONE, ADD, SHOW, REMOVE, DOWNLOAD };
+enum supportedAction { NONE, ADD, SHOW, REMOVE };
 
 void show(kiwix::Library* library, const std::string& bookId)
 {
@@ -57,19 +52,47 @@ void show(kiwix::Library* library, const std::string& bookId)
   std::cout << std::endl;
 }
 
+/* Print correct console usage options */
 void usage()
 {
-  cerr << "Usage:" << endl;
-  cerr << "\tkiwix-manage LIBRARY_PATH add ZIM_PATH "
-          "[--zimPathToSave=../content/foobar.zim] [--current] "
-          "[--url=http://...metalink]"
-       << endl;
-  cerr << "\tkiwix-manage LIBRARY_PATH show [CONTENTID1] [CONTENTID2] ... "
-          "(show everything if no param.)"
-       << endl;
-  cerr << "\tkiwix-manage LIBRARY_PATH remove CONTENTID1 [CONTENTID2]" << endl;
-}
+  std::cout << "Usage:" << std::endl
+            << "\tkiwix-manage LIBRARY_PATH add ZIM_PATH [OPTIONS]" << std::endl
+            << "\tkiwix-manage LIBRARY_PATH remove ZIM_ID [ZIM_ID]..." << std::endl
+            << "\tkiwix-manage LIBRARY_PATH show [ZIM_ID]..." << std::endl
+            << std::endl
 
+            << "Purpose:" << std::endl
+            << "\tManipulates the Kiwix library XML file"
+            << std::endl << std::endl
+
+            << "Arguments:" << std::endl
+            << "\tLIBRARY_PATH\tis the XML library file path."
+            << std::endl << std::endl
+            << "\tACTION\t\tis the pre-defined string to specify the action to run on the XML library file."
+            << std::endl << std::endl
+            << "\t\t\tMust be one of the following values:" << std::endl
+            << "\t\t\t* add: add a ZIM file to the library" << std::endl
+            << "\t\t\t* remove: remove a ZIM file from the library" << std::endl
+            << "\t\t\t* show: show the content of the library"
+            << std::endl << std::endl
+            << "\tZIM_ID\t\tZIM file unique ID"
+            << std::endl << std::endl
+            << "\tOPTIONS\t\tCustom options for \"add\" action:" << std::endl
+            << "\t\t\t--zimPathToSave=CUSTOM_ZIM_PATH to replace the current ZIM file path" << std::endl
+            << "\t\t\t--url=HTTP_ZIM_URL to create an \"url\" attribute for the online version of the ZIM file" << std::endl
+            << std::endl
+
+            << "Examples:" << std::endl
+            << "\tAdd ZIM files to library: kiwix-manage my_library.xml add first.zim second.zim" << std::endl
+            << "\tRemove ZIM files from library: kiwix-manage my_library.xml remove e5c2c003-b49e-2756-5176-5d9c86393dd9" << std::endl
+            << "\tShow all library ZIM files: kiwix-manage my_library.xml show" << std::endl
+            << std::endl
+
+            << "Documentation:" << std::endl
+            << "\tSource code\thttps://github.com/kiwix/kiwix-tools" << std::endl
+            << "\tMore info\thttps://wiki.kiwix.org/wiki/Kiwix-manage" << std::endl
+            << std::endl;
+}
 
 bool handle_show(kiwix::Library* library, const std::string& libraryPath,
                  int argc, char* argv[])
@@ -150,8 +173,8 @@ bool handle_add(kiwix::Library* library, const std::string& libraryPath,
   for(auto i=optind; i<argc; i++) {
     std::string zimPath = argv[i];
     if (!zimPath.empty()) {
-      zimPathToSave = zimPathToSave == "." ? zimPath : zimPathToSave;
-      manager.addBookFromPathAndGetId(zimPath, zimPathToSave, url, false);
+      auto _zimPathToSave = zimPathToSave == "." ? zimPath : zimPathToSave;
+      manager.addBookFromPathAndGetId(zimPath, _zimPathToSave, url, false);
     } else {
       std::cerr << "Invalid zim file path" << std::endl;
       resultCode = 1;
@@ -191,62 +214,6 @@ bool handle_remove(kiwix::Library* library, const std::string& libraryPath,
   return(exitCode);
 }
 
-bool handle_download(kiwix::Library* library, const std::string& libraryPath,
-                     int argc, char* argv[])
-{
-  std::string bookId;
-  bool exitCode = false;
-
-  if (argc > 3) {
-     bookId = argv[3];
-  }
-
-  auto& book = library->getBookById(bookId);
-  auto did = book.getDownloadId();
-  kiwix::Downloader downloader;
-  kiwix::Download* download = nullptr;
-  if (!did.empty()) {
-    std::cout << "try resume " << did << std::endl;
-    try {
-      download = downloader.getDownload(did);
-    } catch(...) {}
-  }
-  if (nullptr == download || download->getStatus() == kiwix::Download::K_UNKNOWN) {
-    download = downloader.startDownload(book.getUrl());
-    book.setDownloadId(download->getDid());
-  }
-  int step = 60*5;
-  while (step--) {
-    download->updateStatus();
-    if (download->getStatus() == kiwix::Download::K_COMPLETE) {
-      auto followingId = download->getFollowedBy();
-      if (followingId.empty()) {
-        book.setPath(download->getPath());
-        book.setDownloadId("");
-        std::cout << "File downloaded to " << book.getPath() << std::endl;
-        break;
-      } else {
-        download = downloader.getDownload(followingId);
-      }
-    } else if (download->getStatus() == kiwix::Download::K_ACTIVE) {
-      std::cout << download->getDid() << " : "
-                << kiwix::beautifyFileSize(download->getCompletedLength()) << "/"
-                << kiwix::beautifyFileSize(download->getTotalLength())
-                << " (" << kiwix::beautifyFileSize(download->getDownloadSpeed()) << "/s) "
-                << " [" << kiwix::beautifyFileSize(download->getVerifiedLength()) << "]"
-                << "[" << step << "]    \n" << std::flush;
-    } else if (download->getStatus() == kiwix::Download::K_ERROR) {
-      std::cout << "File Error" << std::endl;
-      exitCode = true;
-      break;
-    }
-    std::this_thread::sleep_for(std::chrono::seconds(1));
-  }
-
-  downloader.close();
-  return exitCode;
-}
-
 int main(int argc, char** argv)
 {
   string libraryPath = "";
@@ -264,8 +231,6 @@ int main(int argc, char** argv)
       action = SHOW;
     else if (actionString == "remove" || actionString == "delete")
       action = REMOVE;
-    else if (actionString == "download")
-      action = DOWNLOAD;
   }
 
   /* Print usage)) if necessary */
@@ -293,15 +258,12 @@ int main(int argc, char** argv)
     case REMOVE:
       exitCode = handle_remove(&library, libraryPath, argc, argv);
       break;
-    case DOWNLOAD:
-      exitCode = handle_download(&library, libraryPath, argc, argv);
-      break;
     case NONE:
       break;
   }
 
   /* Rewrite the library file */
-  if (action == REMOVE || action == ADD || action == DOWNLOAD) {
+  if (action == REMOVE || action == ADD) {
     library.writeToFile(libraryPath);
   }
 
